@@ -259,6 +259,7 @@ bool K3b::GrowisofsWriter::prepareProcess()
         d->gh->reset( burnDevice(), false );
 
     d->burnedMediumType = burnDevice()->mediaType();
+    d->gh->setMediaType(d->burnedMediumType);
 
     //
     // Never use the -dvd-compat parameter with DVD+RW media
@@ -463,9 +464,10 @@ void K3b::GrowisofsWriter::slotReceivedStderr( const QString& line )
             if( pos != -1 ) {
                 pos += 1;
                 double speed = line.mid( pos, line.indexOf( 'x', pos ) - pos ).toDouble(&ok);
-                if( ok ) {
-                    if( d->lastWritingSpeed != speed )
-                        emit writeSpeed( (int)(speed*d->speedMultiplicator()), d->speedMultiplicator() );
+                if (ok) {
+                    if (d->lastWritingSpeed != speed) {
+                        emit writeSpeed((int)(speed * d->speedMultiplicator()), d->speedMultiplicator());
+                    }
                     d->lastWritingSpeed = speed;
                 }
                 else
